export default {
    "index": 7,
    "lineNumber": 1,
    "column": 8,
    "message": "Unexpected token ["
};